document.addEventListener('DOMContentLoaded', function() {
  // Mobile Menu Toggle
  const mobileMenu = document.querySelector('.mobile-menu');
  const navLinks = document.querySelector('.nav-links');

  mobileMenu.addEventListener('click', function() {
    navLinks.classList.toggle('active');
    
    // Animate hamburger to X
    const spans = this.querySelectorAll('span');
    spans.forEach(span => span.classList.toggle('active'));
  });

  // Smooth Scroll for Navigation Links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      if (target) {
        target.scrollIntoView({
          behavior: 'smooth'
        });
        // Close mobile menu if open
        navLinks.classList.remove('active');
      }
    });
  });

  // Form Submission
  const demoForm = document.getElementById('demo-form');
  if (demoForm) {
    demoForm.addEventListener('submit', function(e) {
      e.preventDefault();
      
      // Animate button to show processing state
      const submitButton = this.querySelector('button[type="submit"]');
      const originalText = submitButton.textContent;
      submitButton.textContent = 'Processing...';
      
      // Simulate form submission
      setTimeout(() => {
        submitButton.textContent = 'Thank You!';
        this.reset();
        
        // Reset button text after 2 seconds
        setTimeout(() => {
          submitButton.textContent = originalText;
        }, 2000);
      }, 1000);
    });
  }

  // Intersection Observer for Fade-in Animations
  const observerOptions = {
    threshold: 0.1,
    rootMargin: '0px 0px -50px 0px'
  };

  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('visible');
        observer.unobserve(entry.target);
      }
    });
  }, observerOptions);

  // Observe all feature cards and steps
  document.querySelectorAll('.feature-card, .step').forEach(elem => {
    elem.style.opacity = '0';
    elem.style.transform = 'translateY(20px)';
    elem.style.transition = 'opacity 0.6s ease-out, transform 0.6s ease-out';
    observer.observe(elem);
  });
});

// Add class for fade-in animation
document.documentElement.style.setProperty('--animate-duration', '0.6s');
